/*
 * File: main.cpp
 * --------------
 * In our example, main.cpp is the client. The code here utilizes the Library
 * class, which itself manages all of our songs. As a result, main.cpp doesn't
 * need to worry about how those songs are stored, or how the different
 * grouping operations are carried out. It can just use that functionality.
 */

#include <string>
#include <iostream>
#include <fstream>

#include "console.h"
#include "simpio.h"
#include "strlib.h"
#include "vector.h"

#include "songs.h"

using namespace std;

// kFileName is the name of the file containing our song data. I wish violent
// thoughts on Windows line endings...
const string kFileName("song-data.txt");

// printSongs will accept a list of songs to be printed to the console. For
// each song, it prints out the title, followed by the album and artist,
// followed by the rating.
void printSongs(Vector<Song> songList);

int main() {
    // The entire initialization process is covered by this single line:
    Library library(kFileName);

    while (true) {
        int response = getInteger("1 for artist, 2 for album, 3 to print all, 0 to quit: ");
        if (response == 0) {
            break;
        } else if (response == 1) {
            string artist = getLine("Enter artist: ");
            printSongs(library.getSongsByArtist(artist));
        } else if (response == 2) {
            string album = getLine("Enter album: ");
            printSongs(library.getSongsByAlbum(album));
        } else if (response == 3) {
            printSongs(library.getAllSongs());
        } else {
            cout << "NO!" << endl;
        }
    }

    return 0;
}

void printSongs(Vector<Song> songList) {
    cout << endl;
    for (int i = 0; i < songList.size(); i++) {
        cout << songList[i].title << endl;
        cout << songList[i].album << ", " << songList[i].artist << endl;
        cout << "Rating: " << songList[i].rating << endl;
        cout << endl;
    }
}
