/*
 * File: songs.cpp
 * ---------------
 * This file provides the implementation details for the interface specified in
 * songs.h. The client shouldn't need to see any of this code to be able to use
 * Song and Library properly.
 */

#include "songs.h"

#include <fstream>
#include "strlib.h"

using namespace std;

// Each function we implement is preceded by Library:: in order to specify that
// we're implementing a function defined to be part of the Library class's
// interface.

Library::Library() {
    // nothing needed!
}

Library::Library(string fileName) {
    ifstream input(fileName.c_str());
    while (true) {
        Song nextSong;
        getline(input, nextSong.artist);
        if (input.fail())
            break;

        getline(input, nextSong.album);
        getline(input, nextSong.title);

        string ratingStr;
        getline(input, ratingStr);
        nextSong.rating = stringToInteger(ratingStr);

        addSong(nextSong);
    }
}

void Library::addSong(Song s) {
    // We are going to store the keys in lower case so that we can make lookup
    // case-insensitive.
    string artistKey = toLowerCase(s.artist);
    string albumKey = toLowerCase(s.album);
    artistMap[artistKey].add(s);
    albumMap[albumKey].add(s);
}

Vector<Song> Library::getAllSongs() {
    Vector<Song> allSongs;
    foreach (string artist in artistMap)
        allSongs += artistMap[artist];

    return allSongs;
}

Vector<Song> Library::getSongsByArtist(string artist) {
    return artistMap.get(toLowerCase(artist));
}

Vector<Song> Library::getSongsByAlbum(string album) {
    return albumMap.get(toLowerCase(album));
}
